@@ -2,20 +2,22 @@
  *
  * rdf_statement.h - RDF Statement definition
  *
- * $Id: rdf_statement.h,v 1.26 2002/12/28 13:49:36 cmdjb Exp $
- *
- * Copyright (C) 2000-2001 David Beckett - http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology - http://www.ilrt.org/
- * University of Bristol - http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2008, David Beckett http://www.dajobe.org/
+ * Copyright (C) 2000-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
- * This package is Free Software or Open Source available under the
- * following licenses (these are alternatives):
- *   1. GNU Lesser General Public License (LGPL)
- *   2. GNU General Public License (GPL)
- *   3. Mozilla Public License (MPL)
+ * This package is Free Software and part of Redland http://librdf.org/
+ * 
+ * It is licensed under the following three licenses as alternatives:
+ *   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
+ *   2. GNU General Public License (GPL) V2 or any newer version
+ *   3. Apache License, V2.0 or any newer version
+ * 
+ * You may not use this file except in compliance with at least one of
+ * the above three licenses.
  * 
  * See LICENSE.html or LICENSE.txt at the top of this package for the
- * full license terms.
+ * complete terms and further detail along with the license texts for
+ * the licenses in COPYING.LIB, COPYING and LICENSE-2.0.txt respectively.
  * 
  * 
  */
@@ -25,88 +27,27 @@
 #ifndef LIBRDF_STATEMENT_H
 #define LIBRDF_STATEMENT_H
 
+#ifdef LIBRDF_INTERNAL
+#include <rdf_statement_internal.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-
-#ifdef LIBRDF_INTERNAL
-
-struct librdf_statement_s
-{
-  librdf_world* world;
-  librdf_node* subject;
-  librdf_node* predicate;
-  librdf_node* object;
-};
-
-/* convienience macros - internal */
-#define LIBRDF_NODE_STATEMENT_SUBJECT(s)   ((s)->subject)
-#define LIBRDF_NODE_STATEMENT_PREDICATE(s) ((s)->predicate)
-#define LIBRDF_NODE_STATEMENT_OBJECT(s)    ((s)->object)
-
-#endif
-
-
-/* class methods */
-void librdf_init_statement(librdf_world *world);
-void librdf_finish_statement(librdf_world *world);
-
-
-/* initialising functions / constructors */
-
-/* Create a new Statement. */
-librdf_statement* librdf_new_statement(librdf_world* world);
-
-/* Create a new Statement from an existing Statement - CLONE */
-librdf_statement* librdf_new_statement_from_statement(librdf_statement* statement);
-/* Create a new Statement from existing Nodes */
-librdf_statement* librdf_new_statement_from_nodes(librdf_world *world, librdf_node* subject, librdf_node* predicate, librdf_node* object);
-
-/* Init a statically allocated statement */
-void librdf_statement_init(librdf_world *world, librdf_statement *statement);
-
-/* Clear a statically allocated statement */
-void librdf_statement_clear(librdf_statement *statement);
-
-/* destructor */
-void librdf_free_statement(librdf_statement* statement);
-
-
-/* functions / methods */
-
-librdf_node* librdf_statement_get_subject(librdf_statement *statement);
-void librdf_statement_set_subject(librdf_statement *statement, librdf_node *subject);
-
-librdf_node* librdf_statement_get_predicate(librdf_statement *statement);
-void librdf_statement_set_predicate(librdf_statement *statement, librdf_node *predicate);
-
-librdf_node* librdf_statement_get_object(librdf_statement *statement);
-void librdf_statement_set_object(librdf_statement *statement, librdf_node *object);
-
-/* convert to a string */
-char *librdf_statement_to_string(librdf_statement *statement);
-/* print it prettily */
-void librdf_statement_print(librdf_statement *statement, FILE *fh);
-
-/* compare two statements */
-int librdf_statement_equals(librdf_statement* statement1, librdf_statement* statement2);
-/* match statement against one with partial content */
-int librdf_statement_match(librdf_statement* statement, librdf_statement* partial_statement);
-
-/* serialising/deserialising */
-size_t librdf_statement_encode(librdf_statement* statement, unsigned char *buffer, size_t length);
-size_t librdf_statement_encode_parts(librdf_statement* statement, librdf_node* context_node, unsigned char *buffer, size_t length, int fields);
-size_t librdf_statement_decode(librdf_statement* statement, unsigned char *buffer, size_t length);
-size_t librdf_statement_decode_parts(librdf_statement* statement, librdf_node** context_node, unsigned char *buffer, size_t length);
-
-
-#ifdef LIBRDF_INTERNAL
-
-/* Or-ed to indicate statement parts via fields arguments to
- *   librdf_statement_encode() 
- *   librdf_new_stream_from_node_iterator()
+/**
+ * librdf_statement_part:
+ * @LIBRDF_STATEMENT_SUBJECT: Subject of a statement.
+ * @LIBRDF_STATEMENT_PREDICATE: Predicate of a statement.
+ * @LIBRDF_STATEMENT_OBJECT: Object of a statement.
+ * @LIBRDF_STATEMENT_ALL: All parts of a statement.
+ *
+ * Flags that are or-ed to indicate statement parts.
+ *
+ * Used in fields arguments to methods such as the public
+ * librdf_statement_encode_parts() librdf_statement_decode_parts()
+ * librdf_new_stream_from_node_iterator() and the internal
+ * librdf_storage_node_stream_to_node_create()
  */
 typedef enum {
   LIBRDF_STATEMENT_SUBJECT   = 1 << 0,
@@ -120,7 +61,77 @@ typedef enum {
 } librdf_statement_part;
 
 
-#endif
+/* initialising functions / constructors */
+
+/* Create a new Statement. */
+REDLAND_API
+librdf_statement* librdf_new_statement(librdf_world* world);
+
+/* Create a new Statement from an existing Statement - CLONE */
+REDLAND_API
+librdf_statement* librdf_new_statement_from_statement(librdf_statement* statement);
+/* Create a new Statement from existing Nodes */
+REDLAND_API
+librdf_statement* librdf_new_statement_from_nodes(librdf_world *world, librdf_node* subject, librdf_node* predicate, librdf_node* object);
+
+/* Init a statically allocated statement */
+REDLAND_API
+void librdf_statement_init(librdf_world *world, librdf_statement *statement);
+
+/* Clear a statically allocated statement */
+REDLAND_API
+void librdf_statement_clear(librdf_statement *statement);
+
+/* destructor */
+REDLAND_API
+void librdf_free_statement(librdf_statement* statement);
+
+
+/* functions / methods */
+
+REDLAND_API
+librdf_node* librdf_statement_get_subject(librdf_statement *statement);
+REDLAND_API
+void librdf_statement_set_subject(librdf_statement *statement, librdf_node *node);
+
+REDLAND_API
+librdf_node* librdf_statement_get_predicate(librdf_statement *statement);
+REDLAND_API
+void librdf_statement_set_predicate(librdf_statement *statement, librdf_node *node);
+
+REDLAND_API
+librdf_node* librdf_statement_get_object(librdf_statement *statement);
+REDLAND_API
+void librdf_statement_set_object(librdf_statement *statement, librdf_node *node);
+
+/* if statement has all fields */
+REDLAND_API
+int librdf_statement_is_complete(librdf_statement *statement);
+
+/* convert to a string */
+REDLAND_API
+unsigned char *librdf_statement_to_string(librdf_statement *statement);
+/* print it prettily */
+REDLAND_API
+void librdf_statement_print(librdf_statement *statement, FILE *fh);
+
+/* compare two statements */
+REDLAND_API
+int librdf_statement_equals(librdf_statement* statement1, librdf_statement* statement2);
+/* match statement against one with partial content */
+REDLAND_API
+int librdf_statement_match(librdf_statement* statement, librdf_statement* partial_statement);
+
+/* serialising/deserialising */
+REDLAND_API
+size_t librdf_statement_encode(librdf_statement* statement, unsigned char *buffer, size_t length);
+REDLAND_API
+size_t librdf_statement_encode_parts(librdf_statement* statement, librdf_node* context_node, unsigned char *buffer, size_t length, librdf_statement_part fields);
+REDLAND_API
+size_t librdf_statement_decode(librdf_statement* statement, unsigned char *buffer, size_t length);
+REDLAND_API
+size_t librdf_statement_decode_parts(librdf_statement* statement, librdf_node** context_node, unsigned char *buffer, size_t length);
+
 
 #ifdef __cplusplus
 }
